/* SquaresEffect.c generated by valac 0.40.4, the Vala compiler
 * generated from SquaresEffect.vala, do not modify */

/* Copyright 2013 Jens Bav
 * Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <gdk/gdk.h>


#define TYPE_SHOTWELL_TRANSITION_DESCRIPTOR (shotwell_transition_descriptor_get_type ())
#define SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor))
#define SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))

typedef struct _ShotwellTransitionDescriptor ShotwellTransitionDescriptor;
typedef struct _ShotwellTransitionDescriptorClass ShotwellTransitionDescriptorClass;
typedef struct _ShotwellTransitionDescriptorPrivate ShotwellTransitionDescriptorPrivate;

#define TYPE_SQUARES_EFFECT_DESCRIPTOR (squares_effect_descriptor_get_type ())
#define SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor))
#define SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))
#define IS_SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define IS_SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define SQUARES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))

typedef struct _SquaresEffectDescriptor SquaresEffectDescriptor;
typedef struct _SquaresEffectDescriptorClass SquaresEffectDescriptorClass;
typedef struct _SquaresEffectDescriptorPrivate SquaresEffectDescriptorPrivate;
enum  {
	SQUARES_EFFECT_DESCRIPTOR_0_PROPERTY,
	SQUARES_EFFECT_DESCRIPTOR_NUM_PROPERTIES
};
static GParamSpec* squares_effect_descriptor_properties[SQUARES_EFFECT_DESCRIPTOR_NUM_PROPERTIES];

#define TYPE_SQUARES_EFFECT (squares_effect_get_type ())
#define SQUARES_EFFECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SQUARES_EFFECT, SquaresEffect))
#define SQUARES_EFFECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SQUARES_EFFECT, SquaresEffectClass))
#define IS_SQUARES_EFFECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SQUARES_EFFECT))
#define IS_SQUARES_EFFECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SQUARES_EFFECT))
#define SQUARES_EFFECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SQUARES_EFFECT, SquaresEffectClass))

typedef struct _SquaresEffect SquaresEffect;
typedef struct _SquaresEffectClass SquaresEffectClass;
typedef struct _SquaresEffectPrivate SquaresEffectPrivate;
enum  {
	SQUARES_EFFECT_0_PROPERTY,
	SQUARES_EFFECT_NUM_PROPERTIES
};
static GParamSpec* squares_effect_properties[SQUARES_EFFECT_NUM_PROPERTIES];

struct _ShotwellTransitionDescriptor {
	GObject parent_instance;
	ShotwellTransitionDescriptorPrivate * priv;
};

struct _ShotwellTransitionDescriptorClass {
	GObjectClass parent_class;
	const gchar* (*get_id) (ShotwellTransitionDescriptor* self);
	const gchar* (*get_pluggable_name) (ShotwellTransitionDescriptor* self);
	SpitTransitionsEffect* (*create) (ShotwellTransitionDescriptor* self, SpitHostInterface* host);
};

struct _SquaresEffectDescriptor {
	ShotwellTransitionDescriptor parent_instance;
	SquaresEffectDescriptorPrivate * priv;
};

struct _SquaresEffectDescriptorClass {
	ShotwellTransitionDescriptorClass parent_class;
};

struct _SquaresEffect {
	GObject parent_instance;
	SquaresEffectPrivate * priv;
};

struct _SquaresEffectClass {
	GObjectClass parent_class;
};

struct _SquaresEffectPrivate {
	gdouble square_count_x;
	gdouble square_count_y;
};


static gpointer squares_effect_descriptor_parent_class = NULL;
static gpointer squares_effect_parent_class = NULL;
static SpitTransitionsEffectIface * squares_effect_spit_transitions_effect_parent_iface = NULL;

GType shotwell_transition_descriptor_get_type (void) G_GNUC_CONST;
GType squares_effect_descriptor_get_type (void) G_GNUC_CONST;
SquaresEffectDescriptor* squares_effect_descriptor_new (GFile* resource_directory);
SquaresEffectDescriptor* squares_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
ShotwellTransitionDescriptor* shotwell_transition_descriptor_construct (GType object_type,
                                                                        GFile* resource_directory);
static const gchar* squares_effect_descriptor_real_get_id (ShotwellTransitionDescriptor* base);
static const gchar* squares_effect_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* base);
static SpitTransitionsEffect* squares_effect_descriptor_real_create (ShotwellTransitionDescriptor* base,
                                                              SpitHostInterface* host);
SquaresEffect* squares_effect_new (void);
SquaresEffect* squares_effect_construct (GType object_type);
GType squares_effect_get_type (void) G_GNUC_CONST;
#define SQUARES_EFFECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SQUARES_EFFECT, SquaresEffectPrivate))
#define SQUARES_EFFECT_DESIRED_FPS 25
#define SQUARES_EFFECT_MIN_FPS 10
#define SQUARES_EFFECT_SQUARE_SIZE 100
static void squares_effect_real_get_fps (SpitTransitionsEffect* base,
                                  gint* desired_fps,
                                  gint* min_fps);
static void squares_effect_real_start (SpitTransitionsEffect* base,
                                SpitTransitionsVisuals* visuals,
                                SpitTransitionsMotion* motion);
static gboolean squares_effect_real_needs_clear_background (SpitTransitionsEffect* base);
static void squares_effect_real_paint (SpitTransitionsEffect* base,
                                SpitTransitionsVisuals* visuals,
                                SpitTransitionsMotion* motion,
                                cairo_t* ctx,
                                gint width,
                                gint height,
                                gint frame_number);
static void squares_effect_real_advance (SpitTransitionsEffect* base,
                                  SpitTransitionsVisuals* visuals,
                                  SpitTransitionsMotion* motion,
                                  gint frame_number);
static void squares_effect_real_cancel (SpitTransitionsEffect* base);
static void squares_effect_finalize (GObject * obj);


SquaresEffectDescriptor*
squares_effect_descriptor_construct (GType object_type,
                                     GFile* resource_directory)
{
	SquaresEffectDescriptor * self = NULL;
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = (SquaresEffectDescriptor*) shotwell_transition_descriptor_construct (object_type, resource_directory);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return self;
#line 160 "SquaresEffect.c"
}


SquaresEffectDescriptor*
squares_effect_descriptor_new (GFile* resource_directory)
{
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return squares_effect_descriptor_construct (TYPE_SQUARES_EFFECT_DESCRIPTOR, resource_directory);
#line 169 "SquaresEffect.c"
}


static const gchar*
squares_effect_descriptor_real_get_id (ShotwellTransitionDescriptor* base)
{
	SquaresEffectDescriptor * self;
	const gchar* result = NULL;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	result = "org.yorba.shotwell.transitions.squares";
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return result;
#line 184 "SquaresEffect.c"
}


static const gchar*
squares_effect_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* base)
{
	SquaresEffectDescriptor * self;
	const gchar* result = NULL;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor);
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	result = _ ("Squares");
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return result;
#line 199 "SquaresEffect.c"
}


static SpitTransitionsEffect*
squares_effect_descriptor_real_create (ShotwellTransitionDescriptor* base,
                                       SpitHostInterface* host)
{
	SquaresEffectDescriptor * self;
	SpitTransitionsEffect* result = NULL;
	SquaresEffect* _tmp0_;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_val_if_fail (SPIT_IS_HOST_INTERFACE (host), NULL);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp0_ = squares_effect_new ();
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TRANSITIONS_TYPE_EFFECT, SpitTransitionsEffect);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return result;
#line 220 "SquaresEffect.c"
}


static void
squares_effect_descriptor_class_init (SquaresEffectDescriptorClass * klass)
{
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	squares_effect_descriptor_parent_class = g_type_class_peek_parent (klass);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_id = (const gchar* (*) (ShotwellTransitionDescriptor *)) squares_effect_descriptor_real_get_id;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_pluggable_name = (const gchar* (*) (ShotwellTransitionDescriptor *)) squares_effect_descriptor_real_get_pluggable_name;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->create = (SpitTransitionsEffect* (*) (ShotwellTransitionDescriptor *, SpitHostInterface*)) squares_effect_descriptor_real_create;
#line 235 "SquaresEffect.c"
}


static void
squares_effect_descriptor_instance_init (SquaresEffectDescriptor * self)
{
}


GType
squares_effect_descriptor_get_type (void)
{
	static volatile gsize squares_effect_descriptor_type_id__volatile = 0;
	if (g_once_init_enter (&squares_effect_descriptor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SquaresEffectDescriptorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) squares_effect_descriptor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SquaresEffectDescriptor), 0, (GInstanceInitFunc) squares_effect_descriptor_instance_init, NULL };
		GType squares_effect_descriptor_type_id;
		squares_effect_descriptor_type_id = g_type_register_static (TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, "SquaresEffectDescriptor", &g_define_type_info, 0);
		g_once_init_leave (&squares_effect_descriptor_type_id__volatile, squares_effect_descriptor_type_id);
	}
	return squares_effect_descriptor_type_id__volatile;
}


SquaresEffect*
squares_effect_construct (GType object_type)
{
	SquaresEffect * self = NULL;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = (SquaresEffect*) g_object_new (object_type, NULL);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return self;
#line 267 "SquaresEffect.c"
}


SquaresEffect*
squares_effect_new (void)
{
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return squares_effect_construct (TYPE_SQUARES_EFFECT);
#line 276 "SquaresEffect.c"
}


static void
squares_effect_real_get_fps (SpitTransitionsEffect* base,
                             gint* desired_fps,
                             gint* min_fps)
{
	SquaresEffect * self;
	gint _vala_desired_fps = 0;
	gint _vala_min_fps = 0;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_vala_desired_fps = SQUARES_EFFECT_DESIRED_FPS;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_vala_min_fps = SQUARES_EFFECT_MIN_FPS;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	if (desired_fps) {
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		*desired_fps = _vala_desired_fps;
#line 298 "SquaresEffect.c"
	}
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	if (min_fps) {
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		*min_fps = _vala_min_fps;
#line 304 "SquaresEffect.c"
	}
}


static void
squares_effect_real_start (SpitTransitionsEffect* base,
                           SpitTransitionsVisuals* visuals,
                           SpitTransitionsMotion* motion)
{
	SquaresEffect * self;
	GdkRectangle _tmp0_ = {0};
	GdkRectangle _tmp1_;
	gint _tmp2_;
	GdkRectangle _tmp3_ = {0};
	GdkRectangle _tmp4_;
	gint _tmp5_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	spit_transitions_visuals_get_to_pos (visuals, &_tmp0_);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp1_ = _tmp0_;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp2_ = _tmp1_.width;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self->priv->square_count_x = (gdouble) ((_tmp2_ / SQUARES_EFFECT_SQUARE_SIZE) + 1);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	spit_transitions_visuals_get_to_pos (visuals, &_tmp3_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp4_ = _tmp3_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp5_ = _tmp4_.height;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self->priv->square_count_y = (gdouble) ((_tmp5_ / SQUARES_EFFECT_SQUARE_SIZE) + 1);
#line 343 "SquaresEffect.c"
}


static gboolean
squares_effect_real_needs_clear_background (SpitTransitionsEffect* base)
{
	SquaresEffect * self;
	gboolean result = FALSE;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	result = TRUE;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	return result;
#line 358 "SquaresEffect.c"
}


static void
squares_effect_real_paint (SpitTransitionsEffect* base,
                           SpitTransitionsVisuals* visuals,
                           SpitTransitionsMotion* motion,
                           cairo_t* ctx,
                           gint width,
                           gint height,
                           gint frame_number)
{
	SquaresEffect * self;
	gdouble alpha = 0.0;
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp11_;
	GdkPixbuf* _tmp12_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (ctx != NULL);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	alpha = spit_transitions_motion_get_alpha (motion, frame_number);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp0_ = spit_transitions_visuals_get_from_pixbuf (visuals);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp1_ = _tmp0_;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	if (_tmp1_ != NULL) {
#line 393 "SquaresEffect.c"
		GdkPixbuf* _tmp2_;
		GdkPixbuf* _tmp3_;
		GdkRectangle _tmp4_ = {0};
		GdkRectangle _tmp5_;
		gint _tmp6_;
		GdkRectangle _tmp7_ = {0};
		GdkRectangle _tmp8_;
		gint _tmp9_;
		gdouble _tmp10_;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp2_ = spit_transitions_visuals_get_from_pixbuf (visuals);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp3_ = _tmp2_;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		spit_transitions_visuals_get_from_pos (visuals, &_tmp4_);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp5_ = _tmp4_;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp6_ = _tmp5_.x;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		spit_transitions_visuals_get_from_pos (visuals, &_tmp7_);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp8_ = _tmp7_;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp9_ = _tmp8_.y;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		gdk_cairo_set_source_pixbuf (ctx, _tmp3_, (gdouble) _tmp6_, (gdouble) _tmp9_);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp10_ = alpha;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		cairo_paint_with_alpha (ctx, 1 - _tmp10_);
#line 425 "SquaresEffect.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp11_ = spit_transitions_visuals_get_to_pixbuf (visuals);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	_tmp12_ = _tmp11_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	if (_tmp12_ != NULL) {
#line 433 "SquaresEffect.c"
		GdkPixbuf* _tmp13_;
		GdkPixbuf* _tmp14_;
		GdkRectangle _tmp15_ = {0};
		GdkRectangle _tmp16_;
		gint _tmp17_;
		GdkRectangle _tmp18_ = {0};
		GdkRectangle _tmp19_;
		gint _tmp20_;
		gdouble _tmp46_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp13_ = spit_transitions_visuals_get_to_pixbuf (visuals);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp14_ = _tmp13_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp15_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp16_ = _tmp15_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp17_ = _tmp16_.x;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp18_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp19_ = _tmp18_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp20_ = _tmp19_.y;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		gdk_cairo_set_source_pixbuf (ctx, _tmp14_, (gdouble) _tmp17_, (gdouble) _tmp20_);
#line 461 "SquaresEffect.c"
		{
			gdouble y = 0.0;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
			y = (gdouble) 0;
#line 466 "SquaresEffect.c"
			{
				gboolean _tmp21_ = FALSE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
				_tmp21_ = TRUE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
				while (TRUE) {
#line 473 "SquaresEffect.c"
					gdouble _tmp23_;
					gdouble _tmp24_;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
					if (!_tmp21_) {
#line 478 "SquaresEffect.c"
						gdouble _tmp22_;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
						_tmp22_ = y;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
						y = _tmp22_ + 1;
#line 484 "SquaresEffect.c"
					}
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
					_tmp21_ = FALSE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
					_tmp23_ = y;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
					_tmp24_ = self->priv->square_count_y;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
					if (!(_tmp23_ <= _tmp24_)) {
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
						break;
#line 496 "SquaresEffect.c"
					}
					{
						gdouble x = 0.0;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
						x = (gdouble) 0;
#line 502 "SquaresEffect.c"
						{
							gboolean _tmp25_ = FALSE;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
							_tmp25_ = TRUE;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
							while (TRUE) {
#line 509 "SquaresEffect.c"
								gdouble _tmp27_;
								gdouble _tmp28_;
								gdouble size = 0.0;
								gdouble _tmp29_;
								gdouble _tmp30_;
								gdouble _tmp31_;
								gdouble _tmp32_;
								gdouble _tmp33_;
								gdouble _tmp34_;
								gdouble _tmp35_;
								GdkRectangle _tmp36_ = {0};
								GdkRectangle _tmp37_;
								gint _tmp38_;
								gdouble _tmp39_;
								GdkRectangle _tmp40_ = {0};
								GdkRectangle _tmp41_;
								gint _tmp42_;
								gdouble _tmp43_;
								gdouble _tmp44_;
								gdouble _tmp45_;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								if (!_tmp25_) {
#line 532 "SquaresEffect.c"
									gdouble _tmp26_;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
									_tmp26_ = x;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
									x = _tmp26_ + 1;
#line 538 "SquaresEffect.c"
								}
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp25_ = FALSE;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp27_ = x;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp28_ = self->priv->square_count_x;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								if (!(_tmp27_ <= _tmp28_)) {
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
									break;
#line 550 "SquaresEffect.c"
								}
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp29_ = alpha;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp30_ = self->priv->square_count_x;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp31_ = x;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp32_ = self->priv->square_count_x;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp33_ = self->priv->square_count_y;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp34_ = y;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp35_ = self->priv->square_count_y;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								size = SQUARES_EFFECT_SQUARE_SIZE * fmin ((gdouble) 1, _tmp29_ + ((((_tmp30_ - _tmp31_) / _tmp32_) + ((_tmp33_ - _tmp34_) / _tmp35_)) / 2.5));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								spit_transitions_visuals_get_to_pos (visuals, &_tmp36_);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp37_ = _tmp36_;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp38_ = _tmp37_.x;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp39_ = x;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								spit_transitions_visuals_get_to_pos (visuals, &_tmp40_);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp41_ = _tmp40_;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp42_ = _tmp41_.y;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp43_ = y;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp44_ = size;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								_tmp45_ = size;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								cairo_rectangle (ctx, _tmp38_ + (_tmp39_ * SQUARES_EFFECT_SQUARE_SIZE), _tmp42_ + (_tmp43_ * SQUARES_EFFECT_SQUARE_SIZE), _tmp44_, _tmp45_);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
								cairo_fill (ctx);
#line 592 "SquaresEffect.c"
							}
						}
					}
				}
			}
		}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		cairo_clip (ctx);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		_tmp46_ = alpha;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
		cairo_paint_with_alpha (ctx, _tmp46_);
#line 605 "SquaresEffect.c"
	}
}


static void
squares_effect_real_advance (SpitTransitionsEffect* base,
                             SpitTransitionsVisuals* visuals,
                             SpitTransitionsMotion* motion,
                             gint frame_number)
{
	SquaresEffect * self;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 623 "SquaresEffect.c"
}


static void
squares_effect_real_cancel (SpitTransitionsEffect* base)
{
	SquaresEffect * self;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 633 "SquaresEffect.c"
}


static void
squares_effect_class_init (SquaresEffectClass * klass)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	squares_effect_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	g_type_class_add_private (klass, sizeof (SquaresEffectPrivate));
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	G_OBJECT_CLASS (klass)->finalize = squares_effect_finalize;
#line 646 "SquaresEffect.c"
}


static void
squares_effect_spit_transitions_effect_interface_init (SpitTransitionsEffectIface * iface)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	squares_effect_spit_transitions_effect_parent_iface = g_type_interface_peek_parent (iface);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->get_fps = (void (*) (SpitTransitionsEffect *, gint*, gint*)) squares_effect_real_get_fps;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->start = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*)) squares_effect_real_start;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->needs_clear_background = (gboolean (*) (SpitTransitionsEffect *)) squares_effect_real_needs_clear_background;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->paint = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*, cairo_t*, gint, gint, gint)) squares_effect_real_paint;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->advance = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*, gint)) squares_effect_real_advance;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	iface->cancel = (void (*) (SpitTransitionsEffect *)) squares_effect_real_cancel;
#line 667 "SquaresEffect.c"
}


static void
squares_effect_instance_init (SquaresEffect * self)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self->priv = SQUARES_EFFECT_GET_PRIVATE (self);
#line 676 "SquaresEffect.c"
}


static void
squares_effect_finalize (GObject * obj)
{
	SquaresEffect * self;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SQUARES_EFFECT, SquaresEffect);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/SquaresEffect.vala"
	G_OBJECT_CLASS (squares_effect_parent_class)->finalize (obj);
#line 688 "SquaresEffect.c"
}


GType
squares_effect_get_type (void)
{
	static volatile gsize squares_effect_type_id__volatile = 0;
	if (g_once_init_enter (&squares_effect_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SquaresEffectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) squares_effect_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SquaresEffect), 0, (GInstanceInitFunc) squares_effect_instance_init, NULL };
		static const GInterfaceInfo spit_transitions_effect_info = { (GInterfaceInitFunc) squares_effect_spit_transitions_effect_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType squares_effect_type_id;
		squares_effect_type_id = g_type_register_static (G_TYPE_OBJECT, "SquaresEffect", &g_define_type_info, 0);
		g_type_add_interface_static (squares_effect_type_id, SPIT_TRANSITIONS_TYPE_EFFECT, &spit_transitions_effect_info);
		g_once_init_leave (&squares_effect_type_id__volatile, squares_effect_type_id);
	}
	return squares_effect_type_id__volatile;
}



